// Thanks takka!

#ifndef CM_LIB_CONV
#define CM_LIB_CONV

/*---------------------------------------------------------------------------
  Shift_JISの一文字をUTF-16に変換する
    sjis: Shift_JIS
    return: UTF-16
---------------------------------------------------------------------------*/
u16 libConvSjis_Utf16(u16 sjis);

/*---------------------------------------------------------------------------
  Shift_JIS文字列をUTF-8Nに変換する
    sjis: Shift_JIS文字列へのポインタ
    utf: UTF-8N文字列へのポインタ
    return: 変換した文字数
---------------------------------------------------------------------------*/
u32 libConvSjis_to_Utf8(void *utf, const void *sjis);

/*---------------------------------------------------------------------------
  Shift_JIS文字列をUTF-16に変換する
    sjis: Shift_JIS文字列へのポインタ
    utf16: UTF-16文字列へのポインタ
    return: 変換した文字数
---------------------------------------------------------------------------*/
u32 libConvSjis_to_Utf16(void *utf16, const void *sjis);

/*---------------------------------------------------------------------------
  UTF-16の一文字をShift_JISに変換する
    utf16: UTF-16
    return: Shift_JIS
---------------------------------------------------------------------------*/
u16 libConvUtf16_Sjis(u16 utf16);

/*---------------------------------------------------------------------------
  UTF-16文字列をShift_JISに変換する
    sjis: Shift_JIS文字列へのポインタ
    utf16: UTF-16文字列へのポインタ
    return: 変換した文字数
---------------------------------------------------------------------------*/
u32 libConvUtf16_to_Sjis(void *sjis, const void *utf16);

/*---------------------------------------------------------------------------
  UFT-8Nの一文字をUTF-16に変換する
    *utf16: 変換後の文字(UTF-16)へのポインタ
    *utf8: UFT-8N文字へのポインタ
    return: UTF-8Nの次の文字へのポインタ
---------------------------------------------------------------------------*/
char* libConvUtf8_Utf16(u16 *utf16, const char *utf8);

/*---------------------------------------------------------------------------
  UFT-8Nの文字列をUTF-16に変換する
    *utf16: 変換後の文字列(UTF-16)へのポインタ
    *utf8: UFT-8N文字列へのポインタ
---------------------------------------------------------------------------*/
void libConvUtf8_to_Utf16(u16 *utf16, const char *utf8);

/*---------------------------------------------------------------------------
  UTF-16の文字列の長さを得る
    *utf16: 文字列(UTF-16)へのポインタ
    return: 文字数
---------------------------------------------------------------------------*/
u16 libConvUtf16len(const u16 *utf16);

/*---------------------------------------------------------------------------
  UFT-8Nの文字列をShift_JISに変換する
    *sjis: 変換後の文字列(Shift_JIS)へのポインタ
    *utf8: UFT-8N文字列へのポインタ
---------------------------------------------------------------------------*/
void libConvUtf8_to_Sjis(void *sjis, const char *utf8);

/*---------------------------------------------------------------------------
  読み込んだ変換ファイルのメモリを解放する
    変換が終わったあとに必ず呼んでください
---------------------------------------------------------------------------*/
void libConvFreeMem();


#endif
